boofun.analysis.complexity
==========================

.. automodule:: boofun.analysis.complexity


   .. rubric:: Functions

   .. autosummary::

      average_sensitivity
      certificate_complexity
      decision_tree_depth
      decision_tree_size
      max_certificate_complexity
      max_sensitivity
      min_sensitivity
      sensitivity

   .. rubric:: Classes

   .. autosummary::

      ComplexityProfile
